#include <UTFT.h>
#include <UTouch.h>
#include <EEPROM.h>
#include <Playtune.h>

// ITDB02-3.2S
UTFT myGLCD(ITDB32S,38,39,40,41);
UTouch      myTouch(6,5,4,3,2);

extern uint8_t SmallFont[];
extern uint8_t BigFont[];
extern uint8_t SevenSegNumFont[];

#define buzzer 10

int sec_now=0;
int min_now=0;
int hour_now=0;
int day_now=1;
int month_now=1;
int year_now=2013;
int dow_now=0;

int chour, cmin; //work copy: time
boolean c_en;
int cday,cmonth,cyear; //work copy: date

int x,y; //touchpad current

unsigned long TimerMark;
unsigned long timercurrent;

boolean refresh=true;  // TFT refresh required
boolean offmode=false; // Hide active?


static char wDay[7][4] =
{
  "Sun", "Mon","Tue","Wed","Thu","Fri","Sat"
};

static char wMonth[12][10] =
{
  "January",
  "February",
  "March",
  "April",
  "May",
  "June",
  "July",
  "August",
  "September",
  "October",
  "November",
  "December"
};

static char wBtn[10][8] = //elements,maxlen
{
  " ",
  "Hide",
  "Set",
  "Alarm",
  "Save",
  "On ",
  "Off",
  "Exit",
  "Date",
  "Time",
};

// alarm
struct AlmItem {
int ahour;
int amin;
boolean is_enabled;
};

AlmItem alarm1 = {0,0,false};
AlmItem alarm2 = {0,0,false};
AlmItem alarm3 = {0,0,false};

boolean alerts_enabled=true; // enable buzzer

// EEPROM struct
// 0 signature 0xCE
// 1 alarm1.ahour
// 2 alarm1.amin
// 3 alarm1.is_enabled
// 4 alarm2.ahour
// 5 alarm2.amin
// 6 alarm2.is_enabled

Playtune pt;


void setup() {
//  Serial.begin(9600);
  
  myGLCD.InitLCD();
  myGLCD.clrScr();

  myTouch.InitTouch();
  myTouch.setPrecision(PREC_MEDIUM);


  // get EEProm data
  if (EEPROM.read(0)==0xCE) {
    alarm1.ahour=EEPROM.read(1);
    alarm1.amin=EEPROM.read(2);
    alarm1.is_enabled=EEPROM.read(3);
    alarm2.ahour=EEPROM.read(4);
    alarm2.amin=EEPROM.read(5);
    alarm2.is_enabled=EEPROM.read(6);
  }

  // buzzer test
    for(int i=0;i<30;i++) 
    {
      digitalWrite(buzzer,HIGH);
      delay(5);
      digitalWrite(buzzer,LOW);
      delay(5);
    }

// init sound 
  pt.tune_initchan (buzzer); 

  TimerMark=millis();
  
  myGLCD.setColor(255, 255, 255);
  myGLCD.setBackColor(0, 0, 0);

}

void loop() {
   timercurrent=millis();
   if ((timercurrent>=TimerMark+1000)) {
   // timer inc/update
   timerinc();
   TimerMark+=1000;
   myDisplay();  
   CheckAlarms();
   }


    if (myTouch.dataAvailable())
    {
      if (offmode) { myGLCD.lcdOn(); offmode=false;
      }
      myTouch.read();
      x=myTouch.getX();
      y=myTouch.getY();
      refresh=true;
//      Serial.print(x); Serial.print("  ");Serial.println(y);
	if (press_map(x,y,20, 200,100,239)) {HideCmdProc();}
	else if (press_map(x,y,120, 200,200,239)) {SetCmdProc();}
	else if (press_map(x,y,220, 200,300,239)) {AlarmCmdProc();}
	else refresh=false;
     } 
}

void timerinc() {
    sec_now++;
    if (sec_now >= 60) {
    min_now++;
    sec_now = 0; 
    alerts_enabled=true;
    }
 
  if (min_now >=60) {
    hour_now++;
    min_now = 0; 
    }
 
  if (hour_now >=24) {
    hour_now=0;
    min_now = 0; 
    new_day();
    }
}

void new_day() {
  int adays[13] = { 0, 31, 29, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31 };
  day_now++;
  if (day_now>adays[month_now]) 
   {day_now=1; month_now++;
    if (month_now>12) {month_now=1; year_now++;}
  }
  cday=day_now; cmonth=month_now; cyear=year_now-2000;
  dow_now=wday();
  refresh=true;
  myGLCD.clrScr();
}
